@@ -37,10 +37,18 @@ class Pywedge_Charts():
         import plotly.graph_objects as go
         from plotly.offline import iplot
         
+        header = widgets.HTML(value="<h2>Pywedge Make_Charts </h2>")
+        display(header)
+
+        
         if len(self.train) > 500:
             from sklearn.model_selection import train_test_split
             test_size = 500/len(self.train)
-            data = self.X.drop(self.c,1)
+            if self.c!=None:
+                data = self.X.drop(self.c,1)
+            else:
+                data = self.X
+                
             target = self.train[self.y]
             X_train, X_test, y_train, y_test = train_test_split(data, target, test_size=test_size, random_state=1)
             train_mc = pd.concat([X_test, y_test], axis=1)
@@ -268,6 +276,9 @@ class Pywedge_Charts():
                                                 annotation_text=corrs.round(2).values)
                 iplot(figure)
 
+        footer = widgets.HTML(value="<h4><em>Charts compiled by Pywedge make_charts </em></h4>")
+        display(footer)
+
 
 class Pre_process_data():
     ''' Cleans the raw dataframe to fed into ML models. Following data pre_processing will be carried out,
